<?php

namespace Drupal\aiprompt_content\Plugin\AIPromptSegment;

use Drupal\aiprompt\Annotation\AIPromptSegment;
use Drupal\aiprompt\Plugin\AIPromptSegmentBase;
use Drupal\aiprompt_content\Entity\AIPrompt;
use Drupal\Core\Annotation\Translation;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides AI Prompt plugin.
 *
 * @AIPromptSegment(
 *   id = "content_prompt",
 *   label = @Translation("Prompt (content storage)"),
 * )
 */
class ContentPrompt extends AIPromptSegmentBase {

  /**
   * {@inheritdoc}
   */
  public function defineConfiguration(): array {
    return [
      'entity_id' => ['default' => NULL],
      'header' => ['default' => ''],
      'footer' => ['default' => '']
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render(): string {
    $prompt = $this->getPrompt();
    $header = $this->getPluginConfigValue('header');
    $footer = $this->getPluginConfigValue('footer');

    $output = '';

    if ($header) {
      $output .= $header . PHP_EOL;
    }
    if ($prompt) {
      $output .= $prompt->toString();
    }
    if ($footer) {
      $output .= PHP_EOL . $footer;
    }

    return $output;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {

    $form['header'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Text before @entity_type', ['@entity_type' => $this->t('prompt')]),
      '#default_value' => $this->getPluginConfigValue('header')
    ];

    $form['entity_id'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Prompt'),
      '#required' => TRUE,
      '#target_type' => 'aiprompt',
      '#default_value' => $this->getPrompt(),
      '#attributes' => ['autocomplete' => ['off']]
    ];

    $form['footer'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Text after @entity_type', ['@entity_type' => $this->t('prompt')]),
      '#default_value' => $this->getPluginConfigValue('footer')
    ];

    $form = parent::buildConfigurationForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state): void {
    if ($form_state->getValue('entity_id') == $this->getAIPromptId()) {
      $form_state->setErrorByName('entity_id', $this->t('Prompt cannot reference itself'));
    }
  }

  /**
   * Helper function to get prompt.
   */
  public function getPrompt() {
    $entity_id = $this->getPluginConfigValue('entity_id');

    if (!empty($entity_id)) {
      return AIPrompt::load($entity_id);
    }
    return NULL;
  }
}