<?php

namespace Drupal\aiprompt\Form;

use Drupal\Component\Utility\Xss;
use Drupal\Core\DependencyInjection\DependencySerializationTrait;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class AIPromptSegmentDeleteForm.
 *
 * Provides a confirm form for deleting the prompt segment from a Prompt.
 */
class AIPromptSegmentDeleteForm extends ConfirmFormBase {

  use DependencySerializationTrait;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  protected $entity_type;
  protected $entity_id;
  protected $entity;
  protected $segment_id;
  protected $segment_data;

  /**
   * Constructs a new Form.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, CurrentRouteMatch $currentRouteMatch) {
    $this->entityTypeManager = $entity_type_manager;
    $this->currentRouteMatch = $currentRouteMatch;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'aiprompt_segment_delete_confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $this->load();

    return $this->t('Are you sure you want to delete segment %name?', 
      ['%name' => Xss::filterAdmin($this->segment_data["plugin_id"])]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    $this->load();

    return new Url("entity.{$this->entity_type}.edit_form", [$this->entity_type => $this->entity->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This action cannot be undone.');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->load();

    $this->entity->deleteSegment($this->segment_id);
    $this->entity->save();

    $this->messenger()->addStatus(
      $this->t('Segment %name has been deleted.', [
        '%name' => $this->segment_id,
      ])
    );

    $form_state->setRedirect("entity.{$this->entity_type}.edit_form", [$this->entity_type => $this->entity->id()]);
  }

  /**
   * Loads necessary data for the form.
   *
   * This method loads the entity, segment data, plugin ID, and plugin instance.
   */
  public function load() {
    if (!empty($this->entity)) return;

    $this->entity_type = 'aiprompt';
    $this->entity = $this->currentRouteMatch->getParameter('aiprompt');

    if (empty($this->entity)) {
      $this->entity_type = 'aiprompt_config';
      $this->entity = $this->currentRouteMatch->getParameter('aiprompt_config');
    }

    $this->segment_id = $this->currentRouteMatch->getParameter('segment_id');
    $this->segment_data = $this->entity->getSegment($this->segment_id);
  }

}