<?php

namespace Drupal\aiprompt;

/**
 * Provides an interface for managing segments.
 *
 * @ingroup aiprompt
 */
interface PromptSegmentsGetSetInterface {

  /**
   * Returns prompt segments.
   *
   * @return array
   *   Array containing prompt segments.
   */
  public function getSegments(): array;

  /**
   * Sets prompt segments.
   *
   * @param array $segments
   *   Array containing prompt segments.
   */
  public function setSegments(array $segments): void;

  /**
   * Sets a segment.
   *
   * @param array $segment
   *   Array containing segment data.
   * @param string|null $machine_name
   *   The machine name of the segment. If not provided, a new one will be generated.
   */
  public function setSegment(array $segment, $machine_name = NULL): void;

  /**
   * Returns a segment.
   *
   * @param string|null $machine_name
   *   The machine name of the segment. If not provided, new empty segment will be returned.
   * @return array
   *   Array containing segment data.
   */
  public function getSegment($machine_name = NULL): array;

  /**
   * Deletes a segment.
   *
   * @param string $machine_name
   *   The machine name of the segment to delete.
   */
  public function deleteSegment(string $machine_name): void;
}